==> deltaspike-1.9.6-source-release.zip: deltaspike-1.9.6/deltaspike/modules/test-control/impl/src/test/java/org/apache/deltaspike/test/testcontrol/mock/uc015/InterceptedBeanTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.test.testcontrol.mock.uc015;

import org.apache.deltaspike.test.category.SeCategory;
import org.apache.deltaspike.testcontrol.api.junit.CdiTestRunner;
import org.junit.Assert;
import org.junit.Test;
import org.junit.experimental.categories.Category;
import org.junit.runner.RunWith;

import javax.inject.Inject;

//Usually NOT needed! Currently only needed due to our arquillian-setup
@Category(SeCategory.class)



@RunWith(CdiTestRunner.class)
public class InterceptedBeanTest
{
    @Inject
    private InterceptionResultStorage interceptionResultStorage;

    @Inject
    private InterceptedBeanClassLevel interceptedBeanClassLevel;

    @Inject
    private InterceptedBeanMethodLevel interceptedBeanMethodLevel;

    @Test
    public void classLevelInterception()
    {
        Assert.assertFalse(this.interceptionResultStorage.isInterceptionDetected());
        this.interceptedBeanClassLevel.test();
        Assert.assertTrue(this.interceptionResultStorage.isInterceptionDetected());
    }

    @Test
    public void methodLevelInterception()
    {
        Assert.assertFalse(this.interceptionResultStorage.isInterceptionDetected());
        this.interceptedBeanMethodLevel.test();
        Assert.assertTrue(this.interceptionResultStorage.isInterceptionDetected());
    }
}

==> deltaspike-2.0.1-source-release.zip: deltaspike-2.0.1/deltaspike/modules/test-control/impl/src/test/java/org/apache/deltaspike/test/testcontrol/mock/uc015/InterceptedBeanTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.test.testcontrol.mock.uc015;

import org.apache.deltaspike.test.category.SeCategory;
import org.apache.deltaspike.testcontrol.api.junit.CdiTestRunner;
import org.junit.Assert;
import org.junit.Test;
import org.junit.experimental.categories.Category;
import org.junit.runner.RunWith;

import jakarta.inject.Inject;

//Usually NOT needed! Currently only needed due to our arquillian-setup
@Category(SeCategory.class)



@RunWith(CdiTestRunner.class)
public class InterceptedBeanTest
{
    @Inject
    private InterceptionResultStorage interceptionResultStorage;

    @Inject
    private InterceptedBeanClassLevel interceptedBeanClassLevel;

    @Inject
    private InterceptedBeanMethodLevel interceptedBeanMethodLevel;

    @Test
    public void classLevelInterception()
    {
        Assert.assertFalse(this.interceptionResultStorage.isInterceptionDetected());
        this.interceptedBeanClassLevel.test();
        Assert.assertTrue(this.interceptionResultStorage.isInterceptionDetected());
    }

    @Test
    public void methodLevelInterception()
    {
        Assert.assertFalse(this.interceptionResultStorage.isInterceptionDetected());
        this.interceptedBeanMethodLevel.test();
        Assert.assertTrue(this.interceptionResultStorage.isInterceptionDetected());
    }
}
